feast.serving package — Feast 0.3.2 documentation

# feast.serving package

## Submodules

## feast.serving.ServingService_pb2 module

class `feast.serving.ServingService_pb2.` `DatasetSource`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  class `FileSource`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `data_format`

      Field feast.serving.DatasetSource.FileSource.data_format

    `file_uris`

      Field feast.serving.DatasetSource.FileSource.file_uris

  `file_source`

    Field feast.serving.DatasetSource.file_source

class `feast.serving.ServingService_pb2.` `FeatureSetRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `feature_names`

    Field feast.serving.FeatureSetRequest.feature_names

  `max_age`

    Field feast.serving.FeatureSetRequest.max_age

  `name`

    Field feast.serving.FeatureSetRequest.name

  `version`

    Field feast.serving.FeatureSetRequest.version

class `feast.serving.ServingService_pb2.` `GetBatchFeaturesRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `dataset_source`

    Field feast.serving.GetBatchFeaturesRequest.dataset_source

  `feature_sets`

    Field feast.serving.GetBatchFeaturesRequest.feature_sets

class `feast.serving.ServingService_pb2.` `GetBatchFeaturesResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `job`

    Field feast.serving.GetBatchFeaturesResponse.job

class `feast.serving.ServingService_pb2.` `GetFeastServingInfoRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>

class `feast.serving.ServingService_pb2.` `GetFeastServingInfoResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `job_staging_location`

    Field feast.serving.GetFeastServingInfoResponse.job_staging_location

  `type`

    Field feast.serving.GetFeastServingInfoResponse.type

  `version`

    Field feast.serving.GetFeastServingInfoResponse.version

class `feast.serving.ServingService_pb2.` `GetJobRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `job`

    Field feast.serving.GetJobRequest.job

class `feast.serving.ServingService_pb2.` `GetJobResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `job`

    Field feast.serving.GetJobResponse.job

class `feast.serving.ServingService_pb2.` `GetOnlineFeaturesRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  class `EntityRow`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    class `FieldsEntry`

      Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

      `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
      `key`

        Field feast.serving.GetOnlineFeaturesRequest.EntityRow.FieldsEntry.key

      `value`

        Field feast.serving.GetOnlineFeaturesRequest.EntityRow.FieldsEntry.value

    `entity_timestamp`

      Field feast.serving.GetOnlineFeaturesRequest.EntityRow.entity_timestamp

    `fields`

      Field feast.serving.GetOnlineFeaturesRequest.EntityRow.fields

  `entity_rows`

    Field feast.serving.GetOnlineFeaturesRequest.entity_rows

  `feature_sets`

    Field feast.serving.GetOnlineFeaturesRequest.feature_sets

  `omit_entities_in_response`

    Field feast.serving.GetOnlineFeaturesRequest.omit_entities_in_response

class `feast.serving.ServingService_pb2.` `GetOnlineFeaturesResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  class `FieldValues`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    class `FieldsEntry`

      Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

      `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
      `key`

        Field feast.serving.GetOnlineFeaturesResponse.FieldValues.FieldsEntry.key

      `value`

        Field feast.serving.GetOnlineFeaturesResponse.FieldValues.FieldsEntry.value

    `fields`

      Field feast.serving.GetOnlineFeaturesResponse.FieldValues.fields

  `field_values`

    Field feast.serving.GetOnlineFeaturesResponse.field_values

class `feast.serving.ServingService_pb2.` `Job`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `data_format`

    Field feast.serving.Job.data_format

  `error`

    Field feast.serving.Job.error

  `file_uris`

    Field feast.serving.Job.file_uris

  `id`

    Field feast.serving.Job.id

  `status`

    Field feast.serving.Job.status

  `type`

    Field feast.serving.Job.type

## feast.serving.ServingService_pb2_grpc module

class `feast.serving.ServingService_pb2_grpc.` `ServingServiceServicer`

  Bases: `object`

  `GetBatchFeatures`(request, context)

    Get batch features asynchronously.

    The client should check the status of the returned job periodically by calling ReloadJob to determine if the job has completed successfully or with an error. If the job completes successfully i.e. status = JOB_STATUS_DONE with no error, then the client can check the file_uris for the location to download feature values data. The client is assumed to have access to these file URIs.

  `GetFeastServingInfo`(request, context)

    Get information about this Feast serving.

  `GetJob`(request, context)

    Get the latest job status for batch feature retrieval.

  `GetOnlineFeatures`(request, context)

    Get online features synchronously.

class `feast.serving.ServingService_pb2_grpc.` `ServingServiceStub`(channel)

  Bases: `object`

`feast.serving.ServingService_pb2_grpc.` `add_ServingServiceServicer_to_server`(servicer, server)

## Module contents